package nl.iobyte.themepark.commands.subcommands.attraction;

import nl.iobyte.commandapi.arguments.EnumArgument;
import nl.iobyte.commandapi.arguments.MessageArgument;
import nl.iobyte.commandapi.arguments.StringArgument;
import nl.iobyte.commandapi.interfaces.SubCommand;
import nl.iobyte.themepark.ThemePark;
import nl.iobyte.themepark.api.attraction.enums.Status;
import nl.iobyte.themepark.api.attraction.objects.Attraction;
import nl.iobyte.themepark.api.attraction.objects.Region;
import nl.iobyte.themepark.api.message.Text;
import nl.iobyte.themepark.commands.arguments.NoAttractionArgument;
import nl.iobyte.themepark.commands.arguments.RegionArgument;
import org.bukkit.Location;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;
import java.util.List;

public class AttractionCreateCommand extends SubCommand {

    public AttractionCreateCommand()  {
        super("themepark.admin", "attraction", "create");

        addSyntax("/themepark attraction create <id> <region_id> <name>")
                .addArgument(new NoAttractionArgument())
                .addArgument(new RegionArgument())
                .addArgument(new MessageArgument());

        addSyntax("/themepark attraction create <id> <region_id> <name> <status>")
                .addArgument(new NoAttractionArgument())
                .addArgument(new RegionArgument())
                .addArgument(new MessageArgument())
                .addArgument(new EnumArgument(Status.values()));

        addSyntax("/themepark attraction create <id> <region_id> <name> <status> <url>")
                .addArgument(new NoAttractionArgument())
                .addArgument(new RegionArgument())
                .addArgument(new MessageArgument())
                .addArgument(new EnumArgument(Status.values()))
                .addArgument(new StringArgument());
    }

    @Override
    public void onPlayerCommand(Player player, List<Object> list, int i) {
        onConsoleCommand(player, list, i);
    }

    @Override
    public void onConsoleCommand(CommandSender  sender, List<Object> list, int i) {
        String id = (String) list.get(0);
        Region region = (Region) list.get(1);
        String name = (String) list.get(2);
        Status status = Status.CONSTRUCTION;
        if(i != 0)
            status = (Status) list.get(3);

        String cover = "https://via.placeholder.com/500x500";
        if(i > 1)
            cover = (String) list.get('4');

        Location location = null;
        if(sender instanceof Player)
            location = ((Player) sender).getLocation();

        ThemePark.getInstance().getAPI().getAttractionService().addAttraction(new Attraction(
                id,
                region.getID(),
                name,
                cover,
                status,
                location
        ));
        sender.sendMessage(Text.color("&6&lThemeParkMC &f➢ &aSuccessfully created attraction &f"+id));
    }

}
